# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.model.v1 import model_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2


class ModelServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListModels = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.model.v1.ModelService/ListModels',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.ListModelsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.ListModelsResponse.FromString,
                )
        self.CreateModel = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.model.v1.ModelService/CreateModel',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.CreateModelRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.CreateModelResponse.FromString,
                )
        self.GetModel = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.model.v1.ModelService/GetModel',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.GetModelRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.GetModelResponse.FromString,
                )
        self.UpdateModel = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.model.v1.ModelService/UpdateModel',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.UpdateModelRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.UpdateModelResponse.FromString,
                )
        self.DeleteModel = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.model.v1.ModelService/DeleteModel',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.DeleteModelRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.DeleteModelResponse.FromString,
                )
        self.DeployModel = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.model.v1.ModelService/DeployModel',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.DeployModelRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.DeployModelResponse.FromString,
                )
        self.PublishModel = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.model.v1.ModelService/PublishModel',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.PublishModelRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.PublishModelResponse.FromString,
                )
        self.CreateModelProfile = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.model.v1.ModelService/CreateModelProfile',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.CreateModelProfileRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.CreateModelProfileResponse.FromString,
                )
        self.GetModelProfile = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.model.v1.ModelService/GetModelProfile',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.GetModelProfileRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.GetModelProfileResponse.FromString,
                )
        self.GetModelMisclass = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.model.v1.ModelService/GetModelMisclass',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.GetMisclassRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.GetMisclassResponse.FromString,
                )
        self.GetModelLogs = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.model.v1.ModelService/GetModelLogs',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.GetModelLogsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.GetModelLogsResponse.FromString,
                )
        self.AbortModel = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.model.v1.ModelService/AbortModel',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.AbortModelRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.AbortModelResponse.FromString,
                )
        self.PauseModel = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.model.v1.ModelService/PauseModel',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.PauseModelRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.PauseModelResponse.FromString,
                )
        self.ResumeModel = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.model.v1.ModelService/ResumeModel',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.ResumeModelRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.ResumeModelResponse.FromString,
                )
        self.CompareModels = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.model.v1.ModelService/CompareModels',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.CompareModelsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.CompareModelsResponse.FromString,
                )
        self.CompileModel = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.model.v1.ModelService/CompileModel',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.CompileModelRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.CompileModelResponse.FromString,
                )
        self.DownloadModel = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.model.v1.ModelService/DownloadModel',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.DownloadModelRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.DownloadModelResponse.FromString,
                )
        self.FlagModel = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.model.v1.ModelService/FlagModel',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.FlagModelRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.FlagModelResponse.FromString,
                )
        self.TestModel = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.model.v1.ModelService/TestModel',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.TestModelRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.TestModelResponse.FromString,
                )


class ModelServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListModels(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateModel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateModel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteModel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployModel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PublishModel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateModelProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelMisclass(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelLogs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AbortModel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PauseModel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResumeModel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CompareModels(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CompileModel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadModel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FlagModel(self, request, context):
        """Flag model 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TestModel(self, request, context):
        """Mark the model to test
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ModelServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListModels': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModels,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.ListModelsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.ListModelsResponse.SerializeToString,
            ),
            'CreateModel': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateModel,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.CreateModelRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.CreateModelResponse.SerializeToString,
            ),
            'GetModel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModel,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.GetModelRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.GetModelResponse.SerializeToString,
            ),
            'UpdateModel': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateModel,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.UpdateModelRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.UpdateModelResponse.SerializeToString,
            ),
            'DeleteModel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteModel,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.DeleteModelRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.DeleteModelResponse.SerializeToString,
            ),
            'DeployModel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployModel,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.DeployModelRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.DeployModelResponse.SerializeToString,
            ),
            'PublishModel': grpc.unary_unary_rpc_method_handler(
                    servicer.PublishModel,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.PublishModelRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.PublishModelResponse.SerializeToString,
            ),
            'CreateModelProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateModelProfile,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.CreateModelProfileRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.CreateModelProfileResponse.SerializeToString,
            ),
            'GetModelProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelProfile,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.GetModelProfileRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.GetModelProfileResponse.SerializeToString,
            ),
            'GetModelMisclass': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelMisclass,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.GetMisclassRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.GetMisclassResponse.SerializeToString,
            ),
            'GetModelLogs': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelLogs,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.GetModelLogsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.GetModelLogsResponse.SerializeToString,
            ),
            'AbortModel': grpc.unary_unary_rpc_method_handler(
                    servicer.AbortModel,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.AbortModelRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.AbortModelResponse.SerializeToString,
            ),
            'PauseModel': grpc.unary_unary_rpc_method_handler(
                    servicer.PauseModel,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.PauseModelRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.PauseModelResponse.SerializeToString,
            ),
            'ResumeModel': grpc.unary_unary_rpc_method_handler(
                    servicer.ResumeModel,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.ResumeModelRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.ResumeModelResponse.SerializeToString,
            ),
            'CompareModels': grpc.unary_unary_rpc_method_handler(
                    servicer.CompareModels,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.CompareModelsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.CompareModelsResponse.SerializeToString,
            ),
            'CompileModel': grpc.unary_unary_rpc_method_handler(
                    servicer.CompileModel,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.CompileModelRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.CompileModelResponse.SerializeToString,
            ),
            'DownloadModel': grpc.unary_unary_rpc_method_handler(
                    servicer.DownloadModel,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.DownloadModelRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.DownloadModelResponse.SerializeToString,
            ),
            'FlagModel': grpc.unary_unary_rpc_method_handler(
                    servicer.FlagModel,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.FlagModelRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.FlagModelResponse.SerializeToString,
            ),
            'TestModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TestModel,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.TestModelRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.TestModelResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.model.v1.ModelService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ModelService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.model.v1.ModelService/ListModels',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.ListModelsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.ListModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.model.v1.ModelService/CreateModel',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.CreateModelRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.CreateModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.model.v1.ModelService/GetModel',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.GetModelRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.GetModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.model.v1.ModelService/UpdateModel',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.UpdateModelRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.UpdateModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.model.v1.ModelService/DeleteModel',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.DeleteModelRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.DeleteModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeployModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.model.v1.ModelService/DeployModel',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.DeployModelRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.DeployModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PublishModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.model.v1.ModelService/PublishModel',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.PublishModelRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.PublishModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateModelProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.model.v1.ModelService/CreateModelProfile',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.CreateModelProfileRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.CreateModelProfileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.model.v1.ModelService/GetModelProfile',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.GetModelProfileRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.GetModelProfileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelMisclass(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.model.v1.ModelService/GetModelMisclass',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.GetMisclassRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.GetMisclassResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelLogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.model.v1.ModelService/GetModelLogs',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.GetModelLogsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.GetModelLogsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AbortModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.model.v1.ModelService/AbortModel',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.AbortModelRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.AbortModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PauseModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.model.v1.ModelService/PauseModel',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.PauseModelRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.PauseModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResumeModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.model.v1.ModelService/ResumeModel',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.ResumeModelRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.ResumeModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CompareModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.model.v1.ModelService/CompareModels',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.CompareModelsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.CompareModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CompileModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.model.v1.ModelService/CompileModel',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.CompileModelRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.CompileModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DownloadModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.model.v1.ModelService/DownloadModel',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.DownloadModelRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.DownloadModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FlagModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.model.v1.ModelService/FlagModel',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.FlagModelRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.FlagModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TestModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.model.v1.ModelService/TestModel',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.TestModelRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_model_dot_v1_dot_model__pb2.TestModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.cronprediction.v1 import cronprediction_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2


class CronPredictionServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListCronPredictions = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService/ListCronPredictions',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.ListCronPredictionsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.ListCronPredictionsResponse.FromString,
                )
        self.CreateCronPrediction = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService/CreateCronPrediction',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.CreateCronPredictionRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.CreateCronPredictionResponse.FromString,
                )
        self.GetCronPrediction = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService/GetCronPrediction',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.GetCronPredictionRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.GetCronPredictionResponse.FromString,
                )
        self.UpdateCronPrediction = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService/UpdateCronPrediction',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.UpdateCronPredictionRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.UpdateCronPredictionResponse.FromString,
                )
        self.DeleteCronPrediction = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService/DeleteCronPrediction',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.DeleteCronPredictionRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.DeleteCronPredictionResponse.FromString,
                )
        self.PauseCronPrediction = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService/PauseCronPrediction',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.PauseCronPredictionRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.PauseCronPredictionResponse.FromString,
                )
        self.ResumeCronPrediction = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService/ResumeCronPrediction',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.ResumeCronPredictionRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.ResumeCronPredictionResponse.FromString,
                )
        self.RunPrediction = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService/RunPrediction',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.RunCronPredictionRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.RunCronPredictionResponse.FromString,
                )


class CronPredictionServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListCronPredictions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateCronPrediction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCronPrediction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateCronPrediction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteCronPrediction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PauseCronPrediction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResumeCronPrediction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunPrediction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CronPredictionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListCronPredictions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListCronPredictions,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.ListCronPredictionsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.ListCronPredictionsResponse.SerializeToString,
            ),
            'CreateCronPrediction': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateCronPrediction,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.CreateCronPredictionRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.CreateCronPredictionResponse.SerializeToString,
            ),
            'GetCronPrediction': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCronPrediction,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.GetCronPredictionRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.GetCronPredictionResponse.SerializeToString,
            ),
            'UpdateCronPrediction': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateCronPrediction,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.UpdateCronPredictionRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.UpdateCronPredictionResponse.SerializeToString,
            ),
            'DeleteCronPrediction': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteCronPrediction,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.DeleteCronPredictionRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.DeleteCronPredictionResponse.SerializeToString,
            ),
            'PauseCronPrediction': grpc.unary_unary_rpc_method_handler(
                    servicer.PauseCronPrediction,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.PauseCronPredictionRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.PauseCronPredictionResponse.SerializeToString,
            ),
            'ResumeCronPrediction': grpc.unary_unary_rpc_method_handler(
                    servicer.ResumeCronPrediction,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.ResumeCronPredictionRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.ResumeCronPredictionResponse.SerializeToString,
            ),
            'RunPrediction': grpc.unary_unary_rpc_method_handler(
                    servicer.RunPrediction,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.RunCronPredictionRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.RunCronPredictionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CronPredictionService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListCronPredictions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService/ListCronPredictions',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.ListCronPredictionsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.ListCronPredictionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateCronPrediction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService/CreateCronPrediction',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.CreateCronPredictionRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.CreateCronPredictionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCronPrediction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService/GetCronPrediction',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.GetCronPredictionRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.GetCronPredictionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateCronPrediction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService/UpdateCronPrediction',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.UpdateCronPredictionRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.UpdateCronPredictionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteCronPrediction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService/DeleteCronPrediction',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.DeleteCronPredictionRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.DeleteCronPredictionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PauseCronPrediction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService/PauseCronPrediction',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.PauseCronPredictionRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.PauseCronPredictionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResumeCronPrediction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService/ResumeCronPrediction',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.ResumeCronPredictionRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.ResumeCronPredictionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunPrediction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.cronprediction.v1.CronPredictionService/RunPrediction',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.RunCronPredictionRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronprediction_dot_v1_dot_cronprediction__pb2.RunCronPredictionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.data.v1 import data_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2


class DataServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ReadFile = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/ReadFile',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsReadFileRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsReadFromStoreResponse.FromString,
                )
        self.ReadFeature = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/ReadFeature',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsReadFeatureRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsReadFromStoreResponse.FromString,
                )
        self.ReadAudio = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/ReadAudio',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsReadAudioRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsReadFromStoreResponse.FromString,
                )
        self.RunDataPipeline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/RunDataPipeline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsRunDataPipelineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsRunDataPipelineResponse.FromString,
                )
        self.RunRecipe = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/RunRecipe',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsRunRecipeRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsRunRecipeResponse.FromString,
                )
        self.WriteFile = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/WriteFile',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsWriteFileRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsReadFromStoreResponse.FromString,
                )
        self.TestDataset = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/TestDataset',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsTestDatasetRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsTestDatasetResponse.FromString,
                )
        self.GenerateDataset = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/GenerateDataset',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsGenerateDatasetRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsGenerateDatasetResponse.FromString,
                )
        self.SplitDataset = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/SplitDataset',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsSplitDatasetRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsSplitDatasetResponse.FromString,
                )
        self.CreateColumnProfile = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/CreateColumnProfile',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateColumnProfileRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateColumnProfileResponse.FromString,
                )
        self.InferSchema = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/InferSchema',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsInferSchemaRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsInferSchemaResponse.FromString,
                )
        self.GetTableView = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/GetTableView',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsGetTableViewRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsGetTableViewResponse.FromString,
                )
        self.SplitDatasetToRungs = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/SplitDatasetToRungs',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsSplitDatasetToRungsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsSplitDatasetToRungsResponse.FromString,
                )
        self.CreateDatasetProfile = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/CreateDatasetProfile',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateDatasetProfileRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateDatasetProfileResponse.FromString,
                )
        self.CreateModelProfile = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/CreateModelProfile',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateModelProfileRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateModelProfileResponse.FromString,
                )
        self.CreateStudyProfile = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/CreateStudyProfile',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateStudyProfileRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateStudyProfileResponse.FromString,
                )
        self.CreateRecipeProfile = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/CreateRecipeProfile',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateRecipeProfileRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateRecipeProfileResponse.FromString,
                )
        self.CreateModelReport = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/CreateModelReport',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateModelReportRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateReportResponse.FromString,
                )
        self.CreateStudyReport = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/CreateStudyReport',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateStudyReportRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateReportResponse.FromString,
                )
        self.CreateDatasetReport = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/CreateDatasetReport',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateDatasetReportRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateReportResponse.FromString,
                )
        self.CreateForecastReport = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/CreateForecastReport',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateForecastReportRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateReportResponse.FromString,
                )
        self.CreateSummaryReport = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/CreateSummaryReport',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateSummaryReportRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateReportResponse.FromString,
                )
        self.AskFE = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/AskFE',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskModelRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskModelResponse.FromString,
                )
        self.AskBaseline = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/AskBaseline',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskBaselineRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskBaselineResponse.FromString,
                )
        self.AskEnsemble = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/AskEnsemble',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskEnsembleRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskEnsembleResponse.FromString,
                )
        self.AskModel = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/AskModel',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskModelRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskModelResponse.FromString,
                )
        self.AskAllModelsForTask = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/AskAllModelsForTask',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskAllModelsForTaskRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskAllModelsForTaskResponse.FromString,
                )
        self.TellPartialModel = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/TellPartialModel',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.TellModelRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.TellModelResponse.FromString,
                )
        self.TellModel = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/TellModel',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.TellModelRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.TellModelResponse.FromString,
                )
        self.PartitionForecastFile = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/PartitionForecastFile',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateForecastPartitionFilesRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateForecastPartitionFilesResponse.FromString,
                )
        self.MergeForecastFile = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/MergeForecastFile',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsMergeForecastFileRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsMergeForecastFileResponse.FromString,
                )
        self.TestModel = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/TestModel',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsTestModelRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsTestModelResponse.FromString,
                )
        self.DsTestConnection = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/DsTestConnection',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsTestConnectionRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsTestConnectionResponse.FromString,
                )
        self.ShutDown = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/ShutDown',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsShutdownRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsShutdownResponse.FromString,
                )
        self.StudyEnded = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/StudyEnded',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsStudyEndedRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsStudyEndedResponse.FromString,
                )
        self.SaveOptimizerDB = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/SaveOptimizerDB',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.SaveOptimizerDBRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.SaveOptimizerDBResponse.FromString,
                )
        self.GetDatabases = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/GetDatabases',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsGetDatabasesRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsGetDatabasesResponse.FromString,
                )
        self.GetTables = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/GetTables',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsGetTablesRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsGetTablesResponse.FromString,
                )
        self.ExecuteSql = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/ExecuteSql',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsExecuteSqlRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsExecuteSqlResponse.FromString,
                )
        self.Snapshot = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/Snapshot',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsSnapshotRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsSnapshotResponse.FromString,
                )
        self.DetectDrift = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/DetectDrift',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsDetectDriftRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsDetectDriftResponse.FromString,
                )
        self.EvalPrediction = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.data.v1.DataService/EvalPrediction',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsEvalPredictionRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsEvalPredictionResponse.FromString,
                )


class DataServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ReadFile(self, request, context):
        """Read from a flat file and create a dataset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadFeature(self, request, context):
        """Read from a feature and create a dataset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadAudio(self, request, context):
        """Read from audio and create an audio dataset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunDataPipeline(self, request, context):
        """Run the data flow
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunRecipe(self, request, context):
        """Run recipe
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteFile(self, request, context):
        """Read from a flat file and create a dataset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TestDataset(self, request, context):
        """Based on the datasource business rules, validate a dataset.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateDataset(self, request, context):
        """Based on the datasource, generate test dataset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SplitDataset(self, request, context):
        """Preform the split. The dataset is assumed to be in the live area after validation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateColumnProfile(self, request, context):
        """Visualize a specific column
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InferSchema(self, request, context):
        """Just infer the datasource, do no plots
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTableView(self, request, context):
        """Just infer the datasource, do no plots
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SplitDatasetToRungs(self, request, context):
        """split the dataset to rungs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDatasetProfile(self, request, context):
        """create dataset profile
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateModelProfile(self, request, context):
        """create model profile
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateStudyProfile(self, request, context):
        """create study profile
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateRecipeProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateModelReport(self, request, context):
        """report services
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateStudyReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDatasetReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateForecastReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSummaryReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AskFE(self, request, context):
        """sample feature engineering pipeline
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AskBaseline(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AskEnsemble(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AskModel(self, request, context):
        """sample model randomly for a given budget
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AskAllModelsForTask(self, request, context):
        """sample model randomly for a given budget
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TellPartialModel(self, request, context):
        """If a model is a partial model (sample < 100%) 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TellModel(self, request, context):
        """for bayaisn optimization, we tell the planner the result of the model evaluation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PartitionForecastFile(self, request, context):
        """Partition the class
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MergeForecastFile(self, request, context):
        """Merge the forecast back to one file.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TestModel(self, request, context):
        """Check for data drift
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DsTestConnection(self, request, context):
        """test connection from python presepective
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ShutDown(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StudyEnded(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SaveOptimizerDB(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDatabases(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTables(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExecuteSql(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Snapshot(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DetectDrift(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EvalPrediction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ReadFile': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadFile,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsReadFileRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsReadFromStoreResponse.SerializeToString,
            ),
            'ReadFeature': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadFeature,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsReadFeatureRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsReadFromStoreResponse.SerializeToString,
            ),
            'ReadAudio': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadAudio,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsReadAudioRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsReadFromStoreResponse.SerializeToString,
            ),
            'RunDataPipeline': grpc.unary_unary_rpc_method_handler(
                    servicer.RunDataPipeline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsRunDataPipelineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsRunDataPipelineResponse.SerializeToString,
            ),
            'RunRecipe': grpc.unary_unary_rpc_method_handler(
                    servicer.RunRecipe,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsRunRecipeRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsRunRecipeResponse.SerializeToString,
            ),
            'WriteFile': grpc.unary_unary_rpc_method_handler(
                    servicer.WriteFile,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsWriteFileRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsReadFromStoreResponse.SerializeToString,
            ),
            'TestDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.TestDataset,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsTestDatasetRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsTestDatasetResponse.SerializeToString,
            ),
            'GenerateDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateDataset,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsGenerateDatasetRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsGenerateDatasetResponse.SerializeToString,
            ),
            'SplitDataset': grpc.unary_unary_rpc_method_handler(
                    servicer.SplitDataset,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsSplitDatasetRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsSplitDatasetResponse.SerializeToString,
            ),
            'CreateColumnProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateColumnProfile,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateColumnProfileRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateColumnProfileResponse.SerializeToString,
            ),
            'InferSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.InferSchema,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsInferSchemaRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsInferSchemaResponse.SerializeToString,
            ),
            'GetTableView': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTableView,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsGetTableViewRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsGetTableViewResponse.SerializeToString,
            ),
            'SplitDatasetToRungs': grpc.unary_unary_rpc_method_handler(
                    servicer.SplitDatasetToRungs,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsSplitDatasetToRungsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsSplitDatasetToRungsResponse.SerializeToString,
            ),
            'CreateDatasetProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDatasetProfile,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateDatasetProfileRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateDatasetProfileResponse.SerializeToString,
            ),
            'CreateModelProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateModelProfile,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateModelProfileRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateModelProfileResponse.SerializeToString,
            ),
            'CreateStudyProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateStudyProfile,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateStudyProfileRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateStudyProfileResponse.SerializeToString,
            ),
            'CreateRecipeProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateRecipeProfile,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateRecipeProfileRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateRecipeProfileResponse.SerializeToString,
            ),
            'CreateModelReport': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateModelReport,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateModelReportRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateReportResponse.SerializeToString,
            ),
            'CreateStudyReport': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateStudyReport,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateStudyReportRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateReportResponse.SerializeToString,
            ),
            'CreateDatasetReport': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDatasetReport,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateDatasetReportRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateReportResponse.SerializeToString,
            ),
            'CreateForecastReport': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateForecastReport,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateForecastReportRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateReportResponse.SerializeToString,
            ),
            'CreateSummaryReport': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSummaryReport,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateSummaryReportRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateReportResponse.SerializeToString,
            ),
            'AskFE': grpc.unary_unary_rpc_method_handler(
                    servicer.AskFE,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskModelRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskModelResponse.SerializeToString,
            ),
            'AskBaseline': grpc.unary_unary_rpc_method_handler(
                    servicer.AskBaseline,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskBaselineRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskBaselineResponse.SerializeToString,
            ),
            'AskEnsemble': grpc.unary_unary_rpc_method_handler(
                    servicer.AskEnsemble,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskEnsembleRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskEnsembleResponse.SerializeToString,
            ),
            'AskModel': grpc.unary_unary_rpc_method_handler(
                    servicer.AskModel,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskModelRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskModelResponse.SerializeToString,
            ),
            'AskAllModelsForTask': grpc.unary_unary_rpc_method_handler(
                    servicer.AskAllModelsForTask,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskAllModelsForTaskRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskAllModelsForTaskResponse.SerializeToString,
            ),
            'TellPartialModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TellPartialModel,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.TellModelRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.TellModelResponse.SerializeToString,
            ),
            'TellModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TellModel,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.TellModelRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.TellModelResponse.SerializeToString,
            ),
            'PartitionForecastFile': grpc.unary_unary_rpc_method_handler(
                    servicer.PartitionForecastFile,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateForecastPartitionFilesRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateForecastPartitionFilesResponse.SerializeToString,
            ),
            'MergeForecastFile': grpc.unary_unary_rpc_method_handler(
                    servicer.MergeForecastFile,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsMergeForecastFileRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsMergeForecastFileResponse.SerializeToString,
            ),
            'TestModel': grpc.unary_unary_rpc_method_handler(
                    servicer.TestModel,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsTestModelRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsTestModelResponse.SerializeToString,
            ),
            'DsTestConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.DsTestConnection,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsTestConnectionRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsTestConnectionResponse.SerializeToString,
            ),
            'ShutDown': grpc.unary_unary_rpc_method_handler(
                    servicer.ShutDown,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsShutdownRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsShutdownResponse.SerializeToString,
            ),
            'StudyEnded': grpc.unary_unary_rpc_method_handler(
                    servicer.StudyEnded,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsStudyEndedRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsStudyEndedResponse.SerializeToString,
            ),
            'SaveOptimizerDB': grpc.unary_unary_rpc_method_handler(
                    servicer.SaveOptimizerDB,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.SaveOptimizerDBRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.SaveOptimizerDBResponse.SerializeToString,
            ),
            'GetDatabases': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDatabases,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsGetDatabasesRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsGetDatabasesResponse.SerializeToString,
            ),
            'GetTables': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTables,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsGetTablesRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsGetTablesResponse.SerializeToString,
            ),
            'ExecuteSql': grpc.unary_unary_rpc_method_handler(
                    servicer.ExecuteSql,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsExecuteSqlRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsExecuteSqlResponse.SerializeToString,
            ),
            'Snapshot': grpc.unary_unary_rpc_method_handler(
                    servicer.Snapshot,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsSnapshotRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsSnapshotResponse.SerializeToString,
            ),
            'DetectDrift': grpc.unary_unary_rpc_method_handler(
                    servicer.DetectDrift,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsDetectDriftRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsDetectDriftResponse.SerializeToString,
            ),
            'EvalPrediction': grpc.unary_unary_rpc_method_handler(
                    servicer.EvalPrediction,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsEvalPredictionRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsEvalPredictionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.data.v1.DataService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ReadFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/ReadFile',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsReadFileRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsReadFromStoreResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadFeature(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/ReadFeature',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsReadFeatureRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsReadFromStoreResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadAudio(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/ReadAudio',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsReadAudioRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsReadFromStoreResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunDataPipeline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/RunDataPipeline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsRunDataPipelineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsRunDataPipelineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunRecipe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/RunRecipe',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsRunRecipeRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsRunRecipeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/WriteFile',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsWriteFileRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsReadFromStoreResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TestDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/TestDataset',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsTestDatasetRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsTestDatasetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GenerateDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/GenerateDataset',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsGenerateDatasetRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsGenerateDatasetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SplitDataset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/SplitDataset',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsSplitDatasetRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsSplitDatasetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateColumnProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/CreateColumnProfile',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateColumnProfileRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateColumnProfileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InferSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/InferSchema',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsInferSchemaRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsInferSchemaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTableView(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/GetTableView',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsGetTableViewRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsGetTableViewResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SplitDatasetToRungs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/SplitDatasetToRungs',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsSplitDatasetToRungsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsSplitDatasetToRungsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDatasetProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/CreateDatasetProfile',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateDatasetProfileRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateDatasetProfileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateModelProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/CreateModelProfile',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateModelProfileRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateModelProfileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateStudyProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/CreateStudyProfile',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateStudyProfileRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateStudyProfileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateRecipeProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/CreateRecipeProfile',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateRecipeProfileRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateRecipeProfileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateModelReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/CreateModelReport',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateModelReportRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateReportResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateStudyReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/CreateStudyReport',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateStudyReportRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateReportResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDatasetReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/CreateDatasetReport',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateDatasetReportRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateReportResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateForecastReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/CreateForecastReport',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateForecastReportRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateReportResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateSummaryReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/CreateSummaryReport',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateSummaryReportRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.CreateReportResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AskFE(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/AskFE',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskModelRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AskBaseline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/AskBaseline',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskBaselineRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskBaselineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AskEnsemble(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/AskEnsemble',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskEnsembleRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskEnsembleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AskModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/AskModel',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskModelRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AskAllModelsForTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/AskAllModelsForTask',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskAllModelsForTaskRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.AskAllModelsForTaskResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TellPartialModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/TellPartialModel',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.TellModelRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.TellModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TellModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/TellModel',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.TellModelRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.TellModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PartitionForecastFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/PartitionForecastFile',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateForecastPartitionFilesRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsCreateForecastPartitionFilesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MergeForecastFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/MergeForecastFile',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsMergeForecastFileRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsMergeForecastFileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TestModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/TestModel',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsTestModelRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsTestModelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DsTestConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/DsTestConnection',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsTestConnectionRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsTestConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ShutDown(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/ShutDown',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsShutdownRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsShutdownResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StudyEnded(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/StudyEnded',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsStudyEndedRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsStudyEndedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SaveOptimizerDB(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/SaveOptimizerDB',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.SaveOptimizerDBRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.SaveOptimizerDBResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDatabases(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/GetDatabases',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsGetDatabasesRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsGetDatabasesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTables(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/GetTables',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsGetTablesRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsGetTablesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExecuteSql(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/ExecuteSql',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsExecuteSqlRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsExecuteSqlResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Snapshot(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/Snapshot',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsSnapshotRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsSnapshotResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DetectDrift(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/DetectDrift',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsDetectDriftRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsDetectDriftResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EvalPrediction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.data.v1.DataService/EvalPrediction',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsEvalPredictionRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_data_dot_v1_dot_data__pb2.DsEvalPredictionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
